summaryrefslogtreecommitdiff
path: root/src/command.hpp
diff options
context:
space:
mode:
authorMartin Sustrik <sustrik@fastmq.commkdir>2009-08-27 10:54:28 +0200
committerMartin Sustrik <sustrik@fastmq.commkdir>2009-08-27 10:54:28 +0200
commit99c5d9283622a0b37ee80f83ff4875c059fc5990 (patch)
tree3460ec503898d2184dc807e47eea679d24d96d5c /src/command.hpp
parentaacdb7a454686bfac93164d0e67e785658d48a3c (diff)
pipes added
Diffstat (limited to 'src/command.hpp')
-rw-r--r--src/command.hpp11
1 files changed, 10 insertions, 1 deletions
diff --git a/src/command.hpp b/src/command.hpp
index 41c7d6c..d3bad79 100644
--- a/src/command.hpp
+++ b/src/command.hpp
@@ -39,6 +39,7 @@ namespace zmq
own,
attach,
bind,
+ revive,
term_req,
term,
term_ack
@@ -65,10 +66,18 @@ namespace zmq
class zmq_engine_t *engine;
} attach;
// Sent between objects to establish pipe(s) between them.
struct {
+ class owned_t *session;
+ class reader_t *in_pipe;
+ class writer_t *out_pipe;
} bind;
+ // Sent by pipe writer to inform dormant pipe reader that there
+ // are messages in the pipe.
+ struct {
+ } revive;
+
// Sent by I/O object ot the socket to request the shutdown of
// the I/O object.
struct {
@@ -65,10 +66,18 @@ namespace zmq
class zmq_engine_t *engine;
} attach;
- // Sent between objects to establish pipe(s) between them.
+ // Sent from session to socket to establish pipe(s) between them.
struct {